==> huaweicloudsdkmetastudio-3.1.96-py2.py3-none-any.whl: huaweicloudsdkmetastudio/v1/model/list_ttsa_jobs_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListTtsaJobsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'ttsa_jobs': 'list[TTSAJob]',
        'x_request_id': 'str'
    }

    attribute_map = {
        'total': 'total',
        'ttsa_jobs': 'ttsa_jobs',
        'x_request_id': 'X-Request-Id'
    }

    def __init__(self, total=None, ttsa_jobs=None, x_request_id=None):
        """ListTtsaJobsResponse

        The model defined in huaweicloud sdk

        :param total: 语音驱动任务总数。
        :type total: int
        :param ttsa_jobs: 语音驱动任务列表。
        :type ttsa_jobs: list[:class:`huaweicloudsdkmetastudio.v1.TTSAJob`]
        :param x_request_id: 
        :type x_request_id: str
        """
        
        super(ListTtsaJobsResponse, self).__init__()

        self._total = None
        self._ttsa_jobs = None
        self._x_request_id = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if ttsa_jobs is not None:
            self.ttsa_jobs = ttsa_jobs
        if x_request_id is not None:
            self.x_request_id = x_request_id

    @property
    def total(self):
        """Gets the total of this ListTtsaJobsResponse.

        语音驱动任务总数。

        :return: The total of this ListTtsaJobsResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ListTtsaJobsResponse.

        语音驱动任务总数。

        :param total: The total of this ListTtsaJobsResponse.
        :type total: int
        """
        self._total = total

    @property
    def ttsa_jobs(self):
        """Gets the ttsa_jobs of this ListTtsaJobsResponse.

        语音驱动任务列表。

        :return: The ttsa_jobs of this ListTtsaJobsResponse.
        :rtype: list[:class:`huaweicloudsdkmetastudio.v1.TTSAJob`]
        """
        return self._ttsa_jobs

    @ttsa_jobs.setter
    def ttsa_jobs(self, ttsa_jobs):
        """Sets the ttsa_jobs of this ListTtsaJobsResponse.

        语音驱动任务列表。

        :param ttsa_jobs: The ttsa_jobs of this ListTtsaJobsResponse.
        :type ttsa_jobs: list[:class:`huaweicloudsdkmetastudio.v1.TTSAJob`]
        """
        self._ttsa_jobs = ttsa_jobs

    @property
    def x_request_id(self):
        """Gets the x_request_id of this ListTtsaJobsResponse.

        :return: The x_request_id of this ListTtsaJobsResponse.
        :rtype: str
        """
        return self._x_request_id

    @x_request_id.setter
    def x_request_id(self, x_request_id):
        """Sets the x_request_id of this ListTtsaJobsResponse.

        :param x_request_id: The x_request_id of this ListTtsaJobsResponse.
        :type x_request_id: str
        """
        self._x_request_id = x_request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListTtsaJobsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkmetastudio-3.1.153-py2.py3-none-any.whl: huaweicloudsdkmetastudio/v1/model/list_ttsa_jobs_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListTtsaJobsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'ttsa_jobs': 'list[TTSAJob]',
        'x_request_id': 'str'
    }

    attribute_map = {
        'total': 'total',
        'ttsa_jobs': 'ttsa_jobs',
        'x_request_id': 'X-Request-Id'
    }

    def __init__(self, total=None, ttsa_jobs=None, x_request_id=None):
        r"""ListTtsaJobsResponse

        The model defined in huaweicloud sdk

        :param total: 语音驱动任务总数。
        :type total: int
        :param ttsa_jobs: 语音驱动任务列表。
        :type ttsa_jobs: list[:class:`huaweicloudsdkmetastudio.v1.TTSAJob`]
        :param x_request_id: 
        :type x_request_id: str
        """
        
        super(ListTtsaJobsResponse, self).__init__()

        self._total = None
        self._ttsa_jobs = None
        self._x_request_id = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if ttsa_jobs is not None:
            self.ttsa_jobs = ttsa_jobs
        if x_request_id is not None:
            self.x_request_id = x_request_id

    @property
    def total(self):
        r"""Gets the total of this ListTtsaJobsResponse.

        语音驱动任务总数。

        :return: The total of this ListTtsaJobsResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        r"""Sets the total of this ListTtsaJobsResponse.

        语音驱动任务总数。

        :param total: The total of this ListTtsaJobsResponse.
        :type total: int
        """
        self._total = total

    @property
    def ttsa_jobs(self):
        r"""Gets the ttsa_jobs of this ListTtsaJobsResponse.

        语音驱动任务列表。

        :return: The ttsa_jobs of this ListTtsaJobsResponse.
        :rtype: list[:class:`huaweicloudsdkmetastudio.v1.TTSAJob`]
        """
        return self._ttsa_jobs

    @ttsa_jobs.setter
    def ttsa_jobs(self, ttsa_jobs):
        r"""Sets the ttsa_jobs of this ListTtsaJobsResponse.

        语音驱动任务列表。

        :param ttsa_jobs: The ttsa_jobs of this ListTtsaJobsResponse.
        :type ttsa_jobs: list[:class:`huaweicloudsdkmetastudio.v1.TTSAJob`]
        """
        self._ttsa_jobs = ttsa_jobs

    @property
    def x_request_id(self):
        r"""Gets the x_request_id of this ListTtsaJobsResponse.

        :return: The x_request_id of this ListTtsaJobsResponse.
        :rtype: str
        """
        return self._x_request_id

    @x_request_id.setter
    def x_request_id(self, x_request_id):
        r"""Sets the x_request_id of this ListTtsaJobsResponse.

        :param x_request_id: The x_request_id of this ListTtsaJobsResponse.
        :type x_request_id: str
        """
        self._x_request_id = x_request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListTtsaJobsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
